@@ -1,9 +1,7 @@
 import argparse
-import json
 import os
 import sys
 from os import PathLike
-from pathlib import Path
 from contextlib import suppress
 from typing import Optional, List
 from typing_extensions import Final
@@ -16,7 +14,6 @@ from docker.api.client import DockerException
 from docker.models.containers import Container
 from docker.models.images import Image
 from docker.types import Mount
-from yaml_dump import yaml_dump
 
 from .decorators import auto_remove, progress_gen
 from . import gvmi
